Introduction
------------

* [About Yii](intro-yii.md) - What is Yii and what is it good for?
* [Upgrading from Version 1.1](intro-upgrade-from-v1.md)


Getting Started
---------------

* [Overview](start-overview.md) - Where should you start from?
* [Starting with Basic App](start-basic.md) - Best for developing a single-tier application by a single person
* [Starting with Advanced App](start-advanced.md) - Best for developing an enterprise application by a team
* [Starting from Scratch](start-scratch.md) - Best for learning every bit of creating an application step-by-step


Basic Concepts
--------------

* [Object Properties](basic-properties.md)
* [Events](basic-events.md)
* [Behaviors](basic-behaviors.md)
* [Object Configurations](basic-configs.md)
* [Class Autoloading](basic-autoloading.md)
* [Path Aliases](basic-alias.md)
* [Extensions](basic-extensions.md)
* [Service Locator](basic-service-locator.md)
* [Dependency Injection Container](basic-di-container.md)


Key Components
--------------

* [MVC Overview](structure-mvc.md)
* [Entry Scripts](structure-entry-scripts.md)
* [Applications](structure-applications.md)
* [Controllers and Actions](structure-controllers.md)
* [Views](structure-views.md)
* [Models](structure-models.md)
* [Action Filters](structure-filters.md)
* [Widgets](structure-widgets.md)
* [Modules](structure-modules.md)


Handling Requests
-----------------

* [Request Lifecycle](runtime-lifecycle.md)
* [Bootstrapping](runtime-bootstrapping.md)
* [Routing](runtime-routing.md)
* [Requests](runtime-requests.md)
* [Responses](runtime-responses.md)
* [Sessions and Cookies](runtime-sessions-cookies.md)
* [URL Parsing and Generation](runtime-url-handling.md)


Collecting Input Data
---------------------

* [Creating Forms](input-forms.md)
* [Input Validation](input-validation.md)
* [Uploading Files](input-file-uploading.md)
* [Inputs for Multiple Models](input-multiple-models.md)


Presenting Data
---------------

* [Data Formatting](output-formatting.md)
* [Pagination](output-pagination.md)
* [Sorting](output-sorting.md)
* [Data Providers](output-data-providers.md)
* [Data Widgets](output-data-widgets.md)
* [Managing Assets](output-assets.md)


Working with Database
---------------------

* [Data Access Objects](db-dao.md) - Connecting to a database, basic queries, transactions and schema manipulation
* [Query Builder](db-query-builder.md) - Querying the database using a simple abstraction layer
* [Active Record](db-active-record.md) - The active record ORM, retrieving and manipulating records and defining relations
* [Migrations](db-migrations.md)
* [Sphinx](db-sphinx.md)
* [Redis](db-redis.md)
* [MongoDB](db-mongodb.md)
* [ElasticSearch](db-elastic-search.md)


Security
--------

* [Authentication](security-authentication.md)
* [Authorization](security-authorization.md)
* [Auth Clients](security-auth-clients.md)
* [Best Practices](security-best-practices.md)


Caching
-------

* [Overview](caching-overview.md)
* [Data Caching](caching-data.md)
* [Fragment and Page Caching](caching-fragment.md)
* [HTTP Caching](caching-http.md)


RESTful Web Services
--------------------

* [Quick Start](rest-quick-start.md)
* [Endpoints](rest-endpoints.md)
* [Resources](rest-resources.md)
* [Data Formatting](rest-data-formatting.md)
* [Authentication](rest-authentication.md)
* [Rate Limiting](rest-rate-limiting.md)
* [Versioning](rest-versioning.md)
* [Caching](rest-caching.md)
* [Error Handling](rest-error-handling.md)
* [Testing](rest-testing.md)
* [Documentation](rest-documentation.md)


Testing
-------

* [Overview](test-overview.md)
* [Unit Tests](test-unit.md)
* [Functional Tests](test-functional.md)
* [Acceptance Tests](test-acceptance.md)
* [Fixtures](test-fixtures.md)


Extending Yii
-------------

* [Creating Extensions](extend-creating-extensions.md)
* [Customizing Core Code](extend-customizing-core.md)
* [Using 3rd-Party Libraries](extend-using-libs.md)
* [Using Yii in 3rd-Party Systems](extend-embedding-in-others.md)
* [Using Yii 1.1 and 2.0 Together](extend-using-v1-v2.md)


Development Tools
-----------------

* [Debug Toolbar and Debugger](tool-debugger.md)
* [Generating Code using Gii](tool-gii.md)
* [Generating API Documentation](tool-apidoc.md)
* [Using Composer](tool-composer.md)


Special Topics
--------------

* [Console Commands](tutorial-console.md)
* [Handling Errors](tutorial-handling-errors.md)
* [Internationalization](tutorial-i18n.md)
* [Logging](tutorial-logging.md)
* [Mailing](tutorial-mailing.md)
* [Performance Tuning](tutorial-performance.md)
* [Template Engines](tutorial-template-engines.md)
* [Theming](tutorial-theming.md)


Widgets
-------

* GridView: link to demo page
* ListView: link to demo page
* DetailView: link to demo page
* ActiveForm: link to demo page
* Pjax: link to demo page
* Menu: link to demo page
* LinkPager: link to demo page
* LinkSorter: link to demo page
* [Bootstrap Widgets](bootstrap-widgets.md)
* [Jquery UI Widgets](jui-widgets.md)



Helpers
-------

* [ArrayHelper](helper-array.md)
* [Html](helper-html.md)
* [Url](helper-url.md)
* [Security](helper-security.md)

